==> devspaces-dashboard-rhel8-container-3.7-46.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-backend/src/devworkspaceClient/services/helpers/prepareCoreV1API.ts <==
/*
 * Copyright (c) 2018-2023 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import * as k8s from '@kubernetes/client-node';
import { retryableExec } from './retryableExec';

export type CoreV1API = Pick<
  k8s.CoreV1Api,
  | 'listNamespace'
  | 'listNamespacedPod'
  | 'readNamespacedPod'
  | 'readNamespacedSecret'
  | 'replaceNamespacedSecret'
  | 'createNamespacedSecret'
  | 'listNamespacedEvent'
>;

export function prepareCoreV1API(kc: k8s.KubeConfig): CoreV1API {
  const coreV1API = kc.makeApiClient(k8s.CoreV1Api);
  return {
    listNamespace: (...args: Parameters<typeof coreV1API.listNamespace>) =>
      retryableExec(() => coreV1API.listNamespace(...args)),
    listNamespacedPod: (...args: Parameters<typeof coreV1API.listNamespacedPod>) =>
      retryableExec(() => coreV1API.listNamespacedPod(...args)),
    readNamespacedPod: (...args: Parameters<typeof coreV1API.readNamespacedPod>) =>
      retryableExec(() => coreV1API.readNamespacedPod(...args)),
    readNamespacedSecret: (...args: Parameters<typeof coreV1API.readNamespacedSecret>) =>
      retryableExec(() => coreV1API.readNamespacedSecret(...args)),
    replaceNamespacedSecret: (...args: Parameters<typeof coreV1API.replaceNamespacedSecret>) =>
      retryableExec(() => coreV1API.replaceNamespacedSecret(...args)),
    createNamespacedSecret: (...args: Parameters<typeof coreV1API.createNamespacedSecret>) =>
      retryableExec(() => coreV1API.createNamespacedSecret(...args)),
    listNamespacedEvent: (...args: Parameters<typeof coreV1API.listNamespacedEvent>) =>
      retryableExec(() => coreV1API.listNamespacedEvent(...args)),
  };
}

==> devspaces-dashboard-rhel8-container-3.8-10.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-backend/src/devworkspaceClient/services/helpers/prepareCoreV1API.ts <==
/*
 * Copyright (c) 2018-2023 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import * as k8s from '@kubernetes/client-node';
import { retryableExec } from './retryableExec';

export type CoreV1API = Pick<
  k8s.CoreV1Api,
  | 'createNamespacedSecret'
  | 'listNamespace'
  | 'listNamespacedEvent'
  | 'listNamespacedPod'
  | 'listNamespacedSecret'
  | 'readNamespacedPod'
  | 'readNamespacedSecret'
  | 'replaceNamespacedSecret'
  | 'deleteNamespacedSecret'
>;

export function prepareCoreV1API(kc: k8s.KubeConfig): CoreV1API {
  const coreV1API = kc.makeApiClient(k8s.CoreV1Api);
  return {
    createNamespacedSecret: (...args: Parameters<typeof coreV1API.createNamespacedSecret>) =>
      retryableExec(() => coreV1API.createNamespacedSecret(...args)),
    listNamespace: (...args: Parameters<typeof coreV1API.listNamespace>) =>
      retryableExec(() => coreV1API.listNamespace(...args)),
    listNamespacedEvent: (...args: Parameters<typeof coreV1API.listNamespacedEvent>) =>
      retryableExec(() => coreV1API.listNamespacedEvent(...args)),
    listNamespacedPod: (...args: Parameters<typeof coreV1API.listNamespacedPod>) =>
      retryableExec(() => coreV1API.listNamespacedPod(...args)),
    listNamespacedSecret: (...args: Parameters<typeof coreV1API.listNamespacedSecret>) =>
      retryableExec(() => coreV1API.listNamespacedSecret(...args)),
    readNamespacedPod: (...args: Parameters<typeof coreV1API.readNamespacedPod>) =>
      retryableExec(() => coreV1API.readNamespacedPod(...args)),
    readNamespacedSecret: (...args: Parameters<typeof coreV1API.readNamespacedSecret>) =>
      retryableExec(() => coreV1API.readNamespacedSecret(...args)),
    replaceNamespacedSecret: (...args: Parameters<typeof coreV1API.replaceNamespacedSecret>) =>
      retryableExec(() => coreV1API.replaceNamespacedSecret(...args)),
    deleteNamespacedSecret: (...args: Parameters<typeof coreV1API.deleteNamespacedSecret>) =>
      retryableExec(() => coreV1API.deleteNamespacedSecret(...args)),
  };
}
